====================================
``psyclone.tests.parse.kernel_test``
====================================

.. automodule:: psyclone.tests.parse.kernel_test

   .. contents::
      :local:

.. currentmodule:: psyclone.tests.parse.kernel_test
